@@ -252,11 +252,10 @@ Lingua::EN::Fathom was written by Kim Ryan <kimryan at cpan dot org>.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2007 Kim Ryan. All rights reserved.
+Copyright (c) 2011 Kim Ryan. All rights reserved.
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.8.4 or,
-at your option, any later version of Perl 5 you may have available.
+it under the same terms as Perl itself.
 
 =cut
 
@@ -266,8 +265,9 @@ package Lingua::EN::Fathom;
 
 use Lingua::EN::Syllable;
 use strict;
+use warnings;
 
-our $VERSION = '1.11';
+our $VERSION = '1.13';
 
 #------------------------------------------------------------------------------
 # Create a new instance of a text object.
@@ -563,7 +563,7 @@ sub _analyse_words
          $text->{num_complex_words}++;
       }
    }
-   # Remove '.'s to denote common abbreviations . By requiring a following space
+   # Remove full stops to denote common abbreviations . By requiring a following space
    # we know the '.' is not also ending the sentence.
    
    # People's titles
